# SF10020UNO

Librería desarrollada en Python para resolver sistemas de ecuaciones lineales y no lineales utilizando los siguientes métodos:

- Eliminación de Gauss
- Gauss-Jordan
- Cramer
- Descomposición LU
- Jacobi
- Gauss-Seidel
- Bisección

## Instalación
Se puede instalar utilizando:

## Uso
```python
from sf10020uno import metodo_gauss

